diff --git a/core/modules/comment/src/Controller/CommentController.php b/core/modules/comment/src/Controller/CommentController.php
index e550afc..49cd043 100644
--- a/core/modules/comment/src/Controller/CommentController.php
+++ b/core/modules/comment/src/Controller/CommentController.php
@@ -226,8 +226,9 @@ public function getReplyForm(Request $request, $entity_type, $entity_id, $field_
         }
         // Load the parent comment.
         $comment = $this->entityManager()->getStorage('comment')->load($pid);
-        // Check if the parent comment is published and belongs to the entity.
-        if (!$comment->isPublished() || ($comment->getCommentedEntityId() != $entity->id())) {
+        // Check if the parent comment is published or user can administer comments
+        //and parent comment belongs to the entity.
+        if ((!$comment->isPublished() && !$account->hasPermission('administer comments')) || ($comment->getCommentedEntityId() != $entity->id())) {
           drupal_set_message($this->t('The comment you are replying to does not exist.'), 'error');
           return new RedirectResponse($uri->toString());
         }
